summaryrefslogtreecommitdiff
path: root/include/git2/commit.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/git2/commit.h')
-rw-r--r--include/git2/commit.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/git2/commit.h b/include/git2/commit.h
index 3c90e8007..4e91b34b9 100644
--- a/include/git2/commit.h
+++ b/include/git2/commit.h
@@ -56,7 +56,7 @@ GIT_INLINE(int) git_commit_lookup_prefix(git_commit **commit, git_repository *re
/**
* Close an open commit
*
* This is a wrapper around git_object_close()
*
* IMPORTANT:
* It *is* necessary to call this method when you stop
@@ -65,9 +65,9 @@ GIT_INLINE(int) git_commit_lookup_prefix(git_commit **commit, git_repository *re
* @param commit the commit to close
*/
-GIT_INLINE(void) git_commit_close(git_commit *commit)
+GIT_INLINE(void) git_commit_free(git_commit *commit)
{
- git_object_close((git_object *) commit);
+ git_object_free((git_object *) commit);
}
/**
@@ -56,7 +56,7 @@ GIT_INLINE(int) git_commit_lookup_prefix(git_commit **commit, git_repository *re
* Close an open commit
*
- * This is a wrapper around git_object_close()
+ * This is a wrapper around git_object_free()
*
* IMPORTANT: